/* BdfServer - Copyright (c) 2023 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.tools.ui.components;

import fr.exemole.bdfserver.api.ui.DataUi;
import net.fichotheque.externalsource.ExternalSourceDef;
import net.fichotheque.tools.externalsource.ExternalSourceDefBuilder;
import net.mapeadores.util.annotation.Nullable;
import net.mapeadores.util.attr.AttributeChange;
import net.mapeadores.util.attr.Attributes;
import net.mapeadores.util.attr.AttributesBuilder;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.text.Label;
import net.mapeadores.util.text.LabelChangeBuilder;
import net.mapeadores.util.text.Labels;


/**
 *
 * @author Vincent Calame
 */
public class DataUiBuilder {

    private final String dataName;
    private final AttributesBuilder attributesBuilder;
    private final ExternalSourceDefBuilder externalSourceDefBuilder;
    private final LabelChangeBuilder labelChangeBuilder;

    private DataUiBuilder(String dataName, String type, @Nullable Attributes initAttributes) {
        this.dataName = dataName;
        this.externalSourceDefBuilder = new ExternalSourceDefBuilder(type);
        this.attributesBuilder = new AttributesBuilder(initAttributes);
        this.labelChangeBuilder = new LabelChangeBuilder();
    }

    public AttributesBuilder getAttributesBuilder() {
        return attributesBuilder;
    }

    public ExternalSourceDefBuilder getExternalSourceDefBuilder() {
        return externalSourceDefBuilder;
    }

    public DataUiBuilder putLabel(Label label) {
        labelChangeBuilder.putLabel(label);
        return this;
    }

    public DataUiBuilder removeLabel(Lang lang) {
        labelChangeBuilder.putRemovedLang(lang);
        return this;
    }

    public DataUiBuilder changesAttribute(AttributeChange attributeChange) {
        this.attributesBuilder.changeAttributes(attributeChange);
        return this;
    }

    public DataUi toDataUi() {
        return new InternalDataUi(dataName, externalSourceDefBuilder.toExternalSourceDef(), labelChangeBuilder.toLabels(), attributesBuilder.toAttributes());
    }

    public static DataUiBuilder init(String name, String type) {
        return new DataUiBuilder(name, type, null);
    }

    public static DataUiBuilder init(String name, String type, @Nullable Attributes initAttributes) {
        return new DataUiBuilder(name, type, initAttributes);
    }

    public static DataUiBuilder derive(DataUi dataUi) {
        ExternalSourceDef externalSourceDef = dataUi.getExternalSourceDef();
        DataUiBuilder dataUiBuilder = new DataUiBuilder(dataUi.getDataName(), externalSourceDef.getType(), dataUi.getAttributes());
        for (Label label : dataUi.getLabels()) {
            dataUiBuilder.putLabel(label);
        }
        for (String paramName : externalSourceDef.getParamNameSet()) {
            dataUiBuilder.externalSourceDefBuilder.addParam(paramName, externalSourceDef.getParam(paramName));
        }
        return dataUiBuilder;
    }


    private static class InternalDataUi implements DataUi {

        private final String dataName;
        private final ExternalSourceDef externalSourceDef;
        private final Labels labels;
        private final Attributes attributes;

        private InternalDataUi(String dataName, ExternalSourceDef externalSourceDef, Labels labels, Attributes attributes) {
            this.dataName = dataName;
            this.externalSourceDef = externalSourceDef;
            this.labels = labels;
            this.attributes = attributes;
        }

        @Override
        public String getName() {
            return DataUi.toComponentName(dataName);
        }

        @Override
        public String getDataName() {
            return dataName;
        }

        @Override
        public ExternalSourceDef getExternalSourceDef() {
            return externalSourceDef;
        }

        @Override
        public Labels getLabels() {
            return labels;
        }

        @Override
        public Attributes getAttributes() {
            return attributes;
        }

    }

}
