/* BdfServer_Html - Copyright (c) 2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.html.forms;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfParameters;
import net.mapeadores.util.attr.AttributeUtils;
import net.mapeadores.util.attr.Attributes;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.localisation.UserLangContext;


/**
 *
 * @author Vincent Calame
 */
public class FormParameters {

    private final BdfServer bdfServer;
    private final UserLangContext userLangContext;
    private final Attributes userAttributes;
    private String namePrefix = null;
    private Lang ficheLang = null;


    public FormParameters(BdfServer bdfServer, UserLangContext userLangContext, Attributes userAttributes) {
        this.bdfServer = bdfServer;
        this.userLangContext = userLangContext;
        this.userAttributes = userAttributes;
    }

    public FormParameters namePrefix(String namePrefix) {
        this.namePrefix = namePrefix;
        return this;
    }

    public String namePrefix() {
        return namePrefix;
    }

    public UserLangContext userLangContext() {
        return userLangContext;
    }

    public Lang workingLang() {
        return userLangContext.getWorkingLang();
    }

    public BdfServer bdfServer() {
        return bdfServer;
    }

    public Lang ficheLang() {
        return ficheLang;
    }

    public FormParameters ficheLang(Lang ficheLang) {
        this.ficheLang = ficheLang;
        return this;
    }

    public Attributes getUserAttributes() {
        return userAttributes;
    }

    public static FormParameters init(BdfServer bdfServer, UserLangContext userLangContext) {
        return new FormParameters(bdfServer, userLangContext, AttributeUtils.EMPTY_ATTRIBUTES);
    }

    public static FormParameters init(BdfParameters bdfParameters) {
        return new FormParameters(bdfParameters.getBdfServer(), bdfParameters.getBdfUser(), bdfParameters.getBdfUser().getPrefs().getAttributes());
    }

}
